@@ -752,9 +752,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		# ComboBoxes
 		o.resolution = int(str(self.ui.resolution.currentText()))
 		o.key = str(self.ui.key.currentText())
+		o.driver = str(self.ui.driver.currentText())
 		o.frontend = str(self.ui.visualization.currentText())
 		if o.frontend == '':
 			o.frontend = None
+		if o.driver == 'default':
+			o.driver = None
 
 		# SpinBoxes
 		o.bpm = int(self.ui.bpm.value())
